@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2019-2022 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2019-2024 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **
 ** This program is free software; you can redistribute it and/or modify it
 ** under the terms of the GNU General Public License as published by the
@@ -46,75 +46,82 @@ struct EmailEqual {
 
 using ContactUMap = std::unordered_map<const std::string, Contact, EmailHash, EmailEqual>;
 struct ContactsCache::Private {
-	Private(const std::string& serialized, const StringVec& personal)
-		: contacts_{deserialize(serialized)},
-		  personal_plain_{make_personal_plain(personal)},
-		  personal_rx_{make_personal_rx(personal)},
-		  dirty_{0}
-	{}
+	Private(Config& config_db)
+		:config_db_{config_db},
+		 contacts_{deserialize(config_db_.get<Config::Id::Contacts>())},
+		 personal_plain_{make_matchers<Config::Id::PersonalAddresses>()},
+		 personal_rx_{make_rx_matchers<Config::Id::PersonalAddresses>()},
+		 ignored_plain_{make_matchers<Config::Id::IgnoredAddresses>()},
+		 ignored_rx_{make_rx_matchers<Config::Id::IgnoredAddresses>()},
+		 dirty_{0},
+		 email_rx_{unwrap(Regex::make(email_rx_str, G_REGEX_OPTIMIZE))}
+		{}
+
+	~Private() { serialize(); }
 
 	ContactUMap deserialize(const std::string&) const;
-	std::string serialize() const;
+	void serialize() const;
 
-	ContactUMap contacts_;
-	std::mutex  mtx_;
+	bool is_valid_email(const std::string& email) const {
+		return email_rx_.matches(email);
+	}
+
+	Config&			config_db_;
+	ContactUMap		contacts_;
+	mutable std::mutex	mtx_;
 
 	const StringVec			personal_plain_;
 	const std::vector<Regex>	personal_rx_;
 
-	size_t dirty_;
+	const StringVec			ignored_plain_;
+	const std::vector<Regex>	ignored_rx_;
+
+	mutable size_t	dirty_;
+	Regex		email_rx_;
 
 private:
-	/**
-	 * Return the non-regex addresses
-	 *
-	 * @param personal
-	 *
-	 * @return
-	 */
-	StringVec make_personal_plain(const StringVec& personal) const {
-		StringVec svec;
-		std::copy_if(personal.begin(),  personal.end(),
-			     std::back_inserter(svec), [&](auto&& p) {
-				     return p.size() < 2 || p.at(0) != '/' ||
-					     p.at(p.length() - 1) != '/';
-			     });
-		return svec;
+	static bool is_rx(const std::string& p)  {
+		return p.size() >= 2 && p.at(0) == '/' && p.at(p.length() - 1) == '/';
 	}
 
-	/**
-	 * Return regexps for the regex-addresses
-	 *
-	 * @param personal
-	 *
-	 * @return
-	 */
-	std::vector<Regex> make_personal_rx(const StringVec& personal) const {
+	template<Config::Id Id> StringVec make_matchers() const {
+		return seq_remove(config_db_.get<Id>(), is_rx);
+	}
+	template<Config::Id Id> std::vector<Regex> make_rx_matchers() const {
 		std::vector<Regex> rxvec;
-		for(auto&& p: personal) {
-			if (p.size() < 2 || p[0] != '/' || p[p.length()- 1] != '/')
+		for (auto&& p: config_db_.get<Id>()) {
+
+			if (!is_rx(p))
 				continue;
-			// a regex pattern.
+			constexpr auto opts{static_cast<GRegexCompileFlags>(G_REGEX_OPTIMIZE|G_REGEX_CASELESS)};
+
+			const auto rxstr{p.substr(1, p.length() - 2)};
 			try {
-				const auto rxstr{p.substr(1, p.length() - 2)};
-				auto opts = static_cast<GRegexCompileFlags>(G_REGEX_OPTIMIZE|G_REGEX_CASELESS);
-				auto rx = Regex::make(rxstr, opts);
-				if (!rx)
-					throw rx.error();
-				rxvec.emplace_back(rx.value());
+				rxvec.push_back(unwrap(Regex::make(rxstr, opts)));
+				mu_debug("match {}: '{}' {}", Config::property<Id>().name,
+					 p, rxvec.back());
 			} catch (const Error& rex) {
-				g_warning("invalid personal address regexp '%s': %s",
-					  p.c_str(),
-					  rex.what());
+				mu_warning("invalid personal address regexp '{}': {}",
+					   p, rex.what());
 			}
 		}
 		return rxvec;
 	}
+
+	/* regexp as per:
+	 *   https://html.spec.whatwg.org/multipage/input.html#valid-e-mail-address
+	 *
+	 * "This requirement is a willful violation of RFC 5322, which defines a
+	 * syntax for email addresses that is simultaneously too strict (before
+	 * the "@" character), too vague (after the "@" character), and too lax
+	 * (allowing comments, whitespace characters, and quoted strings in
+	 * manners unfamiliar to most users) to be of practical use here."
+	 */
+	static constexpr auto email_rx_str =
+		R"(^[a-zA-Z0-9.!#$%&'*+\/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*$)";
+
 };
 
-constexpr auto Separator = "\xff"; // Invalid in UTF-8
-
-
 ContactUMap
 ContactsCache::Private::deserialize(const std::string& serialized) const
 {
@@ -123,9 +130,9 @@ ContactsCache::Private::deserialize(const std::string& serialized) const
 	std::string       line;
 
 	while (getline(ss, line)) {
-		const auto parts = Mu::split(line, Separator);
+		const auto parts = Mu::split(line, SepaChar2);
 		if (G_UNLIKELY(parts.size() != 5)) {
-			g_warning("error: '%s'", line.c_str());
+			mu_warning("error: '{}'", line);
 			continue;
 		}
 		Contact ci(parts[0],                                                  // email
@@ -140,54 +147,63 @@ ContactsCache::Private::deserialize(const std::string& serialized) const
 	return contacts;
 }
 
-ContactsCache::ContactsCache(const std::string& serialized, const StringVec& personal)
-    : priv_{std::make_unique<Private>(serialized, personal)}
+
+void
+ContactsCache::Private::serialize() const
+{
+	if (config_db_.read_only()) {
+		if (dirty_ > 0)
+			mu_critical("dirty data in read-only ccache!"); // bug
+		return;
+	}
+
+	std::string     s;
+	std::unique_lock lock(mtx_);
+
+	if (dirty_ == 0)
+		return; // nothing to do.
+
+	for (auto& item : contacts_) {
+		const auto& ci{item.second};
+		s += mu_format("{}{}{}{}{}{}{}{}{}\n",
+			       ci.email, SepaChar2,
+			       ci.name, SepaChar2,
+			       ci.personal ? 1 : 0, SepaChar2,
+			       ci.message_date, SepaChar2,
+			       ci.frequency);
+	}
+	config_db_.set<Config::Id::Contacts>(s);
+	dirty_ = 0;
+}
+
+ContactsCache::ContactsCache(Config& config_db)
+	: priv_{std::make_unique<Private>(config_db)}
 {}
 
 ContactsCache::~ContactsCache() = default;
 
-std::string
+void
 ContactsCache::serialize() const
 {
-	std::lock_guard<std::mutex> l_{priv_->mtx_};
-	std::string                 s;
+	if (priv_->config_db_.read_only())
+		throw std::runtime_error("cannot serialize read-only contacts-cache");
 
-	for (auto& item : priv_->contacts_) {
-		const auto& ci{item.second};
-		s += Mu::format("%s%s"
-				"%s%s"
-				"%d%s"
-				"%" G_GINT64_FORMAT "%s"
-				"%" G_GINT64_FORMAT "\n",
-				ci.email.c_str(),
-				Separator,
-				ci.name.c_str(),
-				Separator,
-				ci.personal ? 1 : 0,
-				Separator,
-				(gint64)ci.message_date,
-				Separator,
-				(gint64)ci.frequency);
-	}
-
-	priv_->dirty_ = 0;
-
-	return s;
-}
-
-bool
-ContactsCache::dirty() const
-{
-	return priv_->dirty_;
+	priv_->serialize();
 }
 
 void
 ContactsCache::add(Contact&& contact)
 {
-	/* we do _not_ cache invalid email addresses, so we won't offer them in completions etc. It
-	 * should be _rare_, but we've seen cases ( broken local messages) */
-	if (!contact.has_valid_email()) {
-		g_warning("not caching invalid e-mail address '%s'", contact.email.c_str());
+	/* we do _not_ cache invalid email addresses, so we won't offer them in
+	 * completions etc. It should be _rare_, but we've seen cases ( broken
+	 * local messages, and various "fake" messages RSS2Imap etc. */
+	if (!is_valid(contact.email)) {
+		mu_debug("not caching invalid e-mail address '{}'", contact.email);
+		return;
+	}
+
+	if (is_ignored(contact.email)) {
+		/* ignored this address, e.g. 'noreply@example.com */
 		return;
 	}
 
@@ -207,7 +223,7 @@ ContactsCache::add(Contact&& contact)
 		auto email{contact.email};
 		// return priv_->contacts_.emplace(ContactUMap::value_type(email, std::move(contact)))
 		//     .first->second;
-		g_debug("adding contact %s <%s>", contact.name.c_str(), contact.email.c_str());
+		mu_debug("adding contact {} <{}>", contact.name.c_str(), contact.email.c_str());
 		priv_->contacts_.emplace(ContactUMap::value_type(email, std::move(contact)));
 
 	} else {	// existing contact.
@@ -221,8 +237,8 @@ ContactsCache::add(Contact&& contact)
 			existing.tstamp	      = g_get_monotonic_time();
 			existing.message_date = contact.message_date;
 		}
-		g_debug("updating contact %s <%s> (%zu)",
-			contact.name.c_str(), contact.email.c_str(), existing.frequency);
+		mu_debug("updating contact {} <{}> ({})",
+			 contact.name, contact.email, existing.frequency);
 	}
 }
 
@@ -239,7 +255,6 @@ ContactsCache::add(Contacts&& contacts, bool& personal)
 	}
 }
 
-
 const Contact*
 ContactsCache::_find(const std::string& email) const
 {
@@ -325,14 +340,14 @@ ContactsCache::for_each(const EachContactFunc& each_contact) const
 	}
 }
 
-bool
-ContactsCache::is_personal(const std::string& addr) const
+static bool
+address_matches(const std::string& addr, const StringVec& plain, const std::vector<Regex>& regexes)
 {
-	for (auto&& p : priv_->personal_plain_)
+	for (auto&& p : plain)
 		if (g_ascii_strcasecmp(addr.c_str(), p.c_str()) == 0)
 			return true;
 
-	for (auto&& rx : priv_->personal_rx_) {
+	for (auto&& rx : regexes) {
 		if (rx.matches(addr))
 			return true;
 	}
@@ -340,6 +355,25 @@ ContactsCache::is_personal(const std::string& addr) const
 	return false;
 }
 
+bool
+ContactsCache::is_personal(const std::string& addr) const
+{
+	return address_matches(addr, priv_->personal_plain_, priv_->personal_rx_);
+}
+
+bool
+ContactsCache::is_ignored(const std::string& addr) const
+{
+	return address_matches(addr, priv_->ignored_plain_, priv_->ignored_rx_);
+}
+
+bool
+ContactsCache::is_valid(const std::string& addr) const
+{
+	return priv_->is_valid_email(addr);
+}
+
+
 #ifdef BUILD_TESTS
 /*
  * Tests.
@@ -351,7 +385,9 @@ ContactsCache::is_personal(const std::string& addr) const
 static void
 test_mu_contacts_cache_base()
 {
-	Mu::ContactsCache contacts("");
+	MemDb xdb{};
+	Config cdb{xdb};
+	ContactsCache contacts(cdb);
 
 	g_assert_true(contacts.empty());
 	g_assert_cmpuint(contacts.size(), ==, 0);
@@ -395,8 +431,11 @@ test_mu_contacts_cache_base()
 static void
 test_mu_contacts_cache_personal()
 {
-	Mu::StringVec personal = {"foo@example.com", "bar@cuux.org", "/bar-.*@fnorb.f./"};
-	Mu::ContactsCache  contacts{"", personal};
+	MemDb xdb{};
+	Config cdb{xdb};
+	cdb.set<Config::Id::PersonalAddresses>
+		(StringVec{{"foo@example.com", "bar@cuux.org", "/bar-.*@fnorb.f./"}});
+	ContactsCache  contacts{cdb};
 
 	g_assert_true(contacts.is_personal("foo@example.com"));
 	g_assert_true(contacts.is_personal("Bar@CuuX.orG"));
@@ -409,11 +448,44 @@ test_mu_contacts_cache_personal()
 	g_assert_false(contacts.is_personal("bar-zzz@fnorb.xr"));
 }
 
+static void
+test_mu_contacts_cache_ignored()
+{
+	MemDb xdb{};
+	Config cdb{xdb};
+	cdb.set<Config::Id::IgnoredAddresses>
+		(StringVec{{"foo@example.com", "bar@cuux.org", "/bar-.*@fnorb.f./"}});
+	ContactsCache  contacts{cdb};
+
+	g_assert_true(contacts.is_ignored("foo@example.com"));
+	g_assert_true(contacts.is_ignored("Bar@CuuX.orG"));
+	g_assert_true(contacts.is_ignored("bar-123abc@fnorb.fi"));
+	g_assert_true(contacts.is_ignored("bar-zzz@fnorb.fr"));
+
+	g_assert_false(contacts.is_ignored("foo@bar.com"));
+	g_assert_false(contacts.is_ignored("BÂr@CuuX.orG"));
+	g_assert_false(contacts.is_ignored("bar@fnorb.fi"));
+	g_assert_false(contacts.is_ignored("bar-zzz@fnorb.xr"));
+
+	g_assert_cmpuint(contacts.size(),==,0);
+	contacts.add(Mu::Contact{"a@example.com", "a", 123, true, 1000, 0});
+	g_assert_cmpuint(contacts.size(),==,1);
+	contacts.add(Mu::Contact{"foo@example.com", "b", 123, true, 1000, 0}); // ignored
+	contacts.add(Mu::Contact{"bar-123abc@fnorb.fi", "c", 123, true, 1000, 0}); // ignored
+	g_assert_cmpuint(contacts.size(),==,1);
+	contacts.add(Mu::Contact{"b@example.com", "d", 123, true, 1000, 0});
+	g_assert_cmpuint(contacts.size(),==,2);
+}
+
+
 
 static void
 test_mu_contacts_cache_foreach()
 {
-	Mu::ContactsCache ccache("");
+	MemDb xdb{};
+	Config cdb{xdb};
+	ContactsCache ccache(cdb);
+
 	ccache.add(Mu::Contact{"a@example.com", "a", 123, true, 1000, 0});
 	ccache.add(Mu::Contact{"b@example.com", "b", 456, true, 1000, 0});
 
@@ -451,11 +523,11 @@ test_mu_contacts_cache_sort()
 	auto result_chars = [](const Mu::ContactsCache& ccache)->std::string {
 		std::string str;
 		if (g_test_verbose())
-			g_print("contacts-cache:\n");
+			fmt::print("contacts-cache:\n");
 
 		ccache.for_each([&](auto&& contact) {
 			if (g_test_verbose())
-				g_print("\t- %s\n", contact.display_name().c_str());
+				fmt::print("\t- {}\n", contact.display_name());
 			str += contact.name;
 			return true;
 		});
@@ -468,7 +540,10 @@ test_mu_contacts_cache_sort()
 
 	{ /* recent messages, newer comes first */
 
-		Mu::ContactsCache ccache("");
+		MemDb xdb{};
+		Config cdb{xdb};
+		ContactsCache ccache(cdb);
+
 		ccache.add(Mu::Contact{"a@example.com", "a", now, true, 1000, 0});
 		ccache.add(Mu::Contact{"b@example.com", "b", now-1, true, 1000, 0});
 		assert_equal(result_chars(ccache), "ab");
@@ -476,22 +551,30 @@ test_mu_contacts_cache_sort()
 
 	{ /* non-recent messages, more frequent comes first */
 
-		Mu::ContactsCache ccache("");
+		MemDb xdb{};
+		Config cdb{xdb};
+		ContactsCache ccache(cdb);
+
 		ccache.add(Mu::Contact{"a@example.com", "a", now-2*RecentOffset, true, 1000, 0});
 		ccache.add(Mu::Contact{"b@example.com", "b", now-3*RecentOffset, true, 2000, 0});
 		assert_equal(result_chars(ccache), "ba");
 	}
 
 	{ /* personal comes first */
+		MemDb xdb{};
+		Config cdb{xdb};
+		ContactsCache ccache(cdb);
 
-		Mu::ContactsCache ccache("");
 		ccache.add(Mu::Contact{"a@example.com", "a", now-5*RecentOffset, true, 1000, 0});
 		ccache.add(Mu::Contact{"b@example.com", "b", now, false, 8000, 0});
 		assert_equal(result_chars(ccache), "ab");
 	}
 
 	{ /* if all else fails, reverse-alphabetically */
-		Mu::ContactsCache ccache("");
+		MemDb xdb{};
+		Config cdb{xdb};
+		ContactsCache ccache(cdb);
+
 		ccache.add(Mu::Contact{"a@example.com", "a", now, false, 1000, 0});
 		ccache.add(Mu::Contact{"b@example.com", "b", now, false, 1000, 0});
 		g_assert_cmpuint(ccache.size(),==,2);
@@ -499,16 +582,28 @@ test_mu_contacts_cache_sort()
 	}
 }
 
+static void
+test_mu_contacts_valid_address()
+{
+	MemDb xdb{};
+	Config cdb{xdb};
+	ContactsCache ccache(cdb);
+
+	g_assert_true(ccache.is_valid("a@example.com"));
+	g_assert_false(ccache.is_valid("a***@@booa@example..com"));
+}
 
 int
 main(int argc, char* argv[])
 {
 	mu_test_init(&argc, &argv);
 
-	g_test_add_func("/lib/contacts-cache/base", test_mu_contacts_cache_base);
-	g_test_add_func("/lib/contacts-cache/personal", test_mu_contacts_cache_personal);
-	g_test_add_func("/lib/contacts-cache/for-each", test_mu_contacts_cache_foreach);
-	g_test_add_func("/lib/contacts-cache/sort", test_mu_contacts_cache_sort);
+	g_test_add_func("/contacts-cache/base", test_mu_contacts_cache_base);
+	g_test_add_func("/contacts-cache/personal", test_mu_contacts_cache_personal);
+	g_test_add_func("/contacts-cache/ignored", test_mu_contacts_cache_ignored);
+	g_test_add_func("/contacts-cache/for-each", test_mu_contacts_cache_foreach);
+	g_test_add_func("/contacts-cache/sort", test_mu_contacts_cache_sort);
+	g_test_add_func("/contacts-cache/valid-address", test_mu_contacts_valid_address);
 
 	return g_test_run();
 }
