@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2022-2024 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2022-2025 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **
 ** This program is free software; you can redistribute it and/or modify it
 ** under the terms of the GNU General Public License as published by the
@@ -422,6 +422,74 @@ Child
 	}
 }
 
+static void
+test_dups_related_new()
+{
+	TestMap test_msgs;
+/* child (dup vv) */
+	test_msgs.insert({"inbox/new/msg2:1,S",
+			 R"(Message-Id: <edcba@foo.bar>
+In-Reply-To: <abcde@foo.bar>
+From: "Foo Example" <bar@example.com>
+Date: Sat, 06 Aug 2022 13:01:54 -0700
+To: example@example.com
+Subject: Re: test1
+
+Child
+)"});
+	test_msgs.insert({"inbox/new/msg3:1,S",
+R"(Message-Id: <edcba@foo.bar>
+In-Reply-To: <abcde@foo.bar>
+From: "Foo Example" <bar@example.com>
+Date: Sat, 06 Aug 2022 13:01:54 -0700
+To: example@example.com
+Subject: Re: test1
+
+Child
+)"});
+/* child (dup ^^); different file  */
+
+       TempDir tdir;
+       const auto store{make_test_store(tdir.path(), test_msgs, {})};
+	{
+		auto qr = store.run_query("flag:new", Field::Id::Date,
+					  QueryFlags::None);
+		g_assert_true(!!qr);
+		g_assert_false(qr->empty());
+		g_assert_cmpuint(qr->size(), ==, 2);
+	}
+
+	{
+		// direct matches
+		auto qr = store.run_query("flags:new", Field::Id::Date,
+					  QueryFlags::SkipDuplicates);
+		g_assert_true(!!qr);
+		g_assert_false(qr->empty());
+		g_assert_cmpuint(qr->size(), ==, 1);
+	}
+
+	{
+		// direct matches
+		auto qr = store.run_query("flags:new", Field::Id::Date,
+					  QueryFlags::IncludeRelated);
+		g_assert_true(!!qr);
+		g_assert_false(qr->empty());
+		g_assert_cmpuint(qr->size(), ==, 2);
+	}
+
+
+	{
+		// direct matches
+		auto qr = store.run_query("flags:new", Field::Id::Date,
+					  QueryFlags::SkipDuplicates | QueryFlags::IncludeRelated);
+		g_assert_true(!!qr);
+		g_assert_false(qr->empty());
+		g_assert_cmpuint(qr->size(), ==, 1);
+	}
+
+}
+
+
 
 static void
 test_related_missing_root()
@@ -851,6 +919,57 @@ Boo!
 }
 
 
+static void
+test_related_empty_in_reply_to()
+{
+	g_test_bug("2812");
+	// test message sent to self, and copy of received msg.
+
+	const auto test_msg = R"(From: "Edward Mallory" <ed@leviathan.gb>
+To: "Russ Hildebrandt <russ@example.com>
+Subject: New Prospect
+Date: Wed, 07 Dec 2022 18:38:06 +0200
+Message-ID: <875ysdfentbhg.fsf@djcbsoftware.nl>
+MIME-Version: 1.0
+In-Reply-To: <>
+Content-Type: text/plain
+
+Boo!
+)";
+	const TestMap test_msgs = {
+		{"inbox/cur/msg1", test_msg }};
+
+	TempDir tdir;
+	auto store{make_test_store(tdir.path(), test_msgs, {})};
+
+	g_assert_cmpuint(store.size(), ==, 1);
+
+	// normal query should give 1
+	{
+		auto qr = store.run_query("maildir:/inbox", Field::Id::Date,
+					  QueryFlags::None);
+		assert_valid_result(qr);
+		g_assert_cmpuint(qr->size(), ==, 1);
+	}
+
+	// a related query should also give 1
+	{
+		auto qr = store.run_query("maildir:/inbox", Field::Id::Date,
+					  QueryFlags::IncludeRelated);
+		assert_valid_result(qr);
+		g_assert_cmpuint(qr->size(), ==, 1);
+	}
+
+	// a related/threading query should also give 1
+	{
+		auto qr = store.run_query("maildir:/inbox", Field::Id::Date,
+					  QueryFlags::IncludeRelated | QueryFlags::Threading);
+		assert_valid_result(qr);
+		g_assert_cmpuint(qr->size(), ==, 1);
+	}
+}
+
+
 static void
 test_html()
 {
@@ -972,6 +1091,8 @@ main(int argc, char* argv[])
 			test_related);
 	g_test_add_func("/store/query/dups-related",
 			test_dups_related);
+	g_test_add_func("/store/query/dups-related-new",
+			test_dups_related_new);
 	g_test_add_func("/store/query/related-missing-root",
 			test_related_missing_root);
 	g_test_add_func("/store/query/body-matricula",
@@ -986,6 +1107,8 @@ main(int argc, char* argv[])
 			test_subject_kata_containers);
 	g_test_add_func("/store/query/related-dup-threaded",
 			test_related_dup_threaded);
+	g_test_add_func("/store/query/related-empty-in-reply-to",
+			test_related_empty_in_reply_to);
 	g_test_add_func("/store/query/html",
 			test_html);
 	g_test_add_func("/store/query/ngrams",
