@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2008-2022 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2008-2023 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **
 ** This program is free software; you can redistribute it and/or modify it
 ** under the terms of the GNU General Public License as published by the
@@ -29,30 +29,21 @@
 #include <langinfo.h>
 #include <locale.h>
 
+#include "utils/mu-utils.hh"
 #include "utils/mu-test-utils.hh"
+#include "utils/mu-utils-file.hh"
 #include "utils/mu-error.hh"
 
-
 using namespace Mu;
 
-char*
-Mu::test_mu_common_get_random_tmpdir()
+/* LCOV_EXCL_START*/
+bool
+Mu::mu_test_mu_hacker()
 {
-	char* dir;
-	int   res;
-
-	dir = g_strdup_printf("%s%cmu-test-%d%ctest-%x",
-			      g_get_tmp_dir(),
-			      G_DIR_SEPARATOR,
-			      getuid(),
-			      G_DIR_SEPARATOR,
-			      (int)random() * getpid() * (int)time(NULL));
-
-	res = g_mkdir_with_parents(dir, 0700);
-	g_assert(res != -1);
-
-	return dir;
+	return !!g_getenv("MU_HACKER");
 }
+/* LCOV_EXCL_STOP*/
+
 
 const char*
 Mu::set_tz(const char* tz)
@@ -73,15 +64,14 @@ bool
 Mu::set_en_us_utf8_locale()
 {
 	setenv("LC_ALL", "en_US.UTF-8", 1);
-	setlocale(LC_ALL, "en_US.UTF-8");
 
-	if (strcmp(nl_langinfo(CODESET), "UTF-8") != 0) {
-		g_print("Note: Unit tests require the en_US.utf8 locale. "
-			"Ignoring test cases.\n");
-		return FALSE;
-	}
+	if (auto str = setlocale(LC_ALL, "en_US.UTF-8"); !str)
+		return false;
 
-	return TRUE;
+	if (strcmp(nl_langinfo(CODESET), "UTF-8") != 0)
+		return false;
+
+	return true;
 }
 
 static void
@@ -93,13 +83,18 @@ black_hole(void)
 void
 Mu::mu_test_init(int *argc, char ***argv)
 {
-	const auto tmpdir{test_random_tmpdir()};
+	TempDir temp_dir;
 
+	g_unsetenv("XAPIAN_CJK_NGRAM");
 	g_setenv("MU_TEST", "yes", TRUE);
-	g_setenv("XDG_CACHE_HOME", tmpdir.c_str(), TRUE);
+	g_setenv("XDG_CACHE_HOME", temp_dir.path().c_str(), TRUE);
+
+	setlocale(LC_ALL, "");
 
 	g_test_init(argc, argv, NULL);
 
+	g_test_bug_base("https://github.com/djcb/mu/issues/");
+
 	if (!g_test_verbose())
 		g_log_set_handler(
 			NULL,
@@ -108,8 +103,6 @@ Mu::mu_test_init(int *argc, char ***argv)
 			(GLogFunc)black_hole, NULL);
 }
 
-
-
 void
 Mu::allow_warnings()
 {
@@ -118,20 +111,14 @@ Mu::allow_warnings()
 	    {});
 }
 
+Mu::TempDir::TempDir(bool autodelete): autodelete_{autodelete} {
 
+	if (auto res{make_temp_dir()}; !res)
+		throw res.error();
+	else
+		path_ = std::move(*res);
 
-Mu::TempDir::TempDir(bool autodelete): autodelete_{autodelete}
-{
-	GError *err{};
-	gchar *tmpdir = g_dir_make_tmp("mu-tmp-XXXXXX", &err);
-	if (!tmpdir)
-		throw Mu::Error(Error::Code::File, &err,
-				"failed to create temporary directory");
-
-	path_ = tmpdir;
-	g_free(tmpdir);
-
-	g_debug("created '%s'", path_.c_str());
+	mu_debug("created '{}'", path_);
 }
 
 Mu::TempDir::~TempDir()
@@ -140,16 +127,14 @@ Mu::TempDir::~TempDir()
 		return; /* nothing to do */
 
 	if (!autodelete_) {
-		g_debug("_not_ deleting %s", path_.c_str());
+		mu_debug("_not_ deleting {}", path_);
 		return;
 	}
 
-	/* ugly */
-	GError *err{};
-	const auto cmd{format("/bin/rm -rf '%s'", path_.c_str())};
-	if (!g_spawn_command_line_sync(cmd.c_str(), NULL, NULL, NULL, &err)) {
-		g_warning("error: %s\n", err ? err->message : "?");
-		g_clear_error(&err);
+	if (auto&& res{run_command0({RM_PROGRAM, "-fr", path_})}; !res) {
+		/* LCOV_EXCL_START*/
+		mu_warning("error removing {}: {}", path_, format_as(res.error()));
+		/* LCOV_EXCL_STOP*/
 	} else
-		g_debug("removed '%s'", path_.c_str());
+		mu_debug("removed '{}'", path_);
 }
