@@ -40,10 +40,9 @@ output_error(const std::string& what, bool use_color)
 	using Color = MaybeAnsi::Color;
 	MaybeAnsi col{use_color};
 
-	std::cerr << col.fg(Color::Red) << "error" << col.reset() << ": "
-		  << col.fg(Color::BrightYellow)
-		  << what << col.reset() << "\n";
-
+	mu_printerrln("{}error{}: {}{}{}",
+		      col.fg(Color::Red), col.reset(),
+		      col.fg(Color::BrightYellow), what, col.reset());
 }
 
 static int
@@ -59,34 +58,37 @@ handle_result(const Result<void>& res, const Mu::Options& opts)
 	if (!res.error().is_soft_error())
 		output_error(res.error().what(), !opts.nocolor);
 	else
-		std::cerr <<  col.fg(Color::BrightBlue) << res.error().what() << '\n';
-
-	std::cerr << col.fg(Color::Green);
+		mu_printerrln("{}{}{}",
+			      col.fg(Color::BrightBlue), res.error().what(), col.reset());
 
 	// perhaps give some useful hint on how to solve it.
-	switch (res.error().code()) {
-	case Error::Code::InvalidArgument:
-		break;
-	case Error::Code::StoreLock:
-		std::cerr << "Perhaps mu is already running?\n";
-		break;
-	case Error::Code::SchemaMismatch:
-		std::cerr << "Please (re)initialize mu with 'mu init' "
-			  << "see mu-init(1) for details\n";
-		break;
-	default:
-		break; /* nothing to do */
-	}
+	if (!res.error().hint().empty())
+		mu_printerrln("{}hint{}: {}{}{}",
+			      col.fg(Color::Blue), col.reset(),
+			      col.fg(Color::Green), res.error().hint(), col.reset());
 
-	std::cerr << col.reset();
+	if (res.error().exit_code() != 0 && !res.error().is_soft_error()) {
+		mu_warning("mu finishing with error: {}",
+			   format_as(res.error()));
+		if (const auto& hint = res.error().hint(); !hint.empty())
+			mu_info("hint: {}", hint);
+	}
 
 	return res.error().exit_code();
 }
 
 int
-main(int argc, char* argv[])
+main(int argc, char* argv[]) try
 {
-	setlocale(LC_ALL, "");
+	/*
+	 * We handle this through explicit options
+	 */
+	g_unsetenv("XAPIAN_CJK_NGRAM");
+
+	/*
+	 * set up locale
+	 */
+	::setlocale(LC_ALL, "");
 
 	/*
 	 * read command-line options
@@ -100,23 +102,16 @@ main(int argc, char* argv[])
 		return 0;
 	}
 
-	/*
-	 * there's a subcommand
-	 */
-
-	/*
-	 * set up logging
-	 */
+	// setup logging
 	Logger::Options lopts{Logger::Options::None};
 	if (opts->log_stderr)
 		lopts |= Logger::Options::StdOutErr;
 	if (opts->debug)
 		lopts |= Logger::Options::Debug;
-	if (g_getenv("MU_TEST"))
+	if (!!g_getenv("MU_TEST"))
 		lopts |= Logger::Options::File;
 
-	const auto logger = Logger::make(opts->runtime_path(RuntimePath::LogFile),
-					 lopts);
+	const auto logger{Logger::make(opts->runtime_path(RuntimePath::LogFile), lopts)};
 	if (!logger) {
 		output_error(logger.error().what(), !opts->nocolor);
 		return logger.error().exit_code();
@@ -126,4 +121,16 @@ main(int argc, char* argv[])
 	 * handle sub command
 	 */
 	return handle_result(mu_cmd_execute(*opts), *opts);
+
+	// exceptions should have been handled earlier, but catch them here,
+	// just in case...
+} catch (const std::logic_error& le) {
+	mu_printerrln("caught logic-error: {}", le.what());
+	return 97;
+} catch (const std::runtime_error& re) {
+	mu_printerrln("caught runtime-error: {}", re.what());
+	return 98;
+} catch (...) {
+	mu_printerrln("caught exception");
+	return 99;
 }
