@@ -1,6 +1,6 @@
-;;; mu4e-actions.el -- part of mu4e, the mu mail user agent -*- lexical-binding: t -*-
+;;; mu4e-actions.el --- Actions for messages/attachments -*- lexical-binding: t -*-
 
-;; Copyright (C) 2011-2022 Dirk-Jan C. Binnema
+;; Copyright (C) 2011-2023 Dirk-Jan C. Binnema
 
 ;; Author: Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 ;; Maintainer: Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
@@ -28,11 +28,13 @@
 ;;; Code:
 
 (require 'ido)
+(require 'browse-url)
 
 (require 'mu4e-helpers)
 (require 'mu4e-message)
 (require 'mu4e-search)
 (require 'mu4e-contacts)
+(require 'mu4e-lists)
 
 ;;; Count lines
 
@@ -167,7 +169,7 @@ Otherwise return nil."
     (save-excursion
       (goto-char (point-min))
       (if (re-search-forward regexp nil t)
-          (replace-match to-string nil nil)))))
+          (replace-match to-string t nil)))))
 
 (declare-function mu4e--server-add "mu4e-server")
 (defun mu4e--refresh-message (path)
@@ -213,7 +215,7 @@ would add \"tag\" and \"long tag\", and remove \"oldtag\"."
        (t
         (setq taglist (push tag taglist)))))
 
-    (setq taglist (sort (delete-dups taglist) 'string<))
+    (setq taglist (delete "" (sort (delete-dups taglist) 'string<)))
     (setq tagstr (mapconcat 'identity taglist sep))
 
     (setq tagstr (replace-regexp-in-string "[\\&]" "\\\\\\&" tagstr))
@@ -247,6 +249,27 @@ the message."
          nil nil nil
          msgid (and (eq major-mode 'mu4e-view-mode)
                     (not (eq mu4e-split-view 'single-window))))))))
-;;; _
+
+
+;;; Mailing list URLS
+
+(defun mu4e-action-browse-list-archive (msg)
+  "Browse the archive for a mailing list message MSG.
+See `mu4e-mailing-list-archive-url'."
+  (interactive (list (mu4e-message-at-point)))
+  (if-let* ((url (mu4e-mailing-list-archive-url msg)))
+    (browse-url url)
+    (mu4e-warn "No archive available for this message")))
+
+(defun mu4e-action-copy-list-archive-url (msg)
+  "Copy the archive url for a mailing list message MSG.
+See `mu4e-mailing-list-archive-url'."
+  (interactive (list (mu4e-message-at-point)))
+  (let ((url (mu4e-mailing-list-archive-url msg)))
+    (if (stringp url)
+        (kill-new url)
+      (mu4e-warn "Cannot get archive URL for this message"))))
+
+;;;
 (provide 'mu4e-actions)
 ;;; mu4e-actions.el ends here
